:github_url: https://github.com/fabiangeisler/pyshotgrid/blob/master/src/pyshotgrid/__init__.py

API Reference
=============

.. automodule:: pyshotgrid
    :members:

.. toctree::
   :maxdepth: 2
   :caption: Modules:

   modules/core
   modules/sg_default_entities
